#
# spec file for package python-octaviaclient
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-octaviaclient
Version:        3.7.0
Release:        1.1
Summary:        Octavia Plugin for the OpenStack Command-line Client
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://docs.openstack.org/python-octaviaclient
Source0:        https://files.pythonhosted.org/packages/source/p/python-octaviaclient/python-octaviaclient-3.7.0.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python3-openstackclient >= 3.12.0
BuildRequires:  python3-oslotest
BuildRequires:  python3-requests-mock
BuildRequires:  python3-stestr
BuildRequires:  python3-testscenarios
BuildArch:      noarch

%description
The Python Octavia Client (python-octaviaclient) is a command-line client for
the OpenStack Load Balancing service.

%package -n python3-octaviaclient
Summary:        Octavia Plugin for the OpenStack Command-line Client
Requires:       python3-Babel
Requires:       python3-cliff >= 2.8.0
Requires:       python3-keystoneauth1 >= 3.18.0
Requires:       python3-netifaces
Requires:       python3-neutronclient >= 6.7.0
Requires:       python3-openstackclient >= 3.12.0
Requires:       python3-osc-lib >= 1.14.1
Requires:       python3-oslo.serialization >= 2.18.0
Requires:       python3-oslo.utils >= 3.33.0
Requires:       python3-requests >= 2.14.2

%description -n python3-octaviaclient
The Python Octavia Client (python-octaviaclient) is a command-line client for
the OpenStack Load Balancing service.

This package contains the Python 3.x module.

%package -n python-octaviaclient-doc
Summary:        Documentation for OpenStack Octavia API Client
Group:          Documentation/HTML
BuildRequires:  python3-Sphinx
BuildRequires:  python3-openstackdocstheme
BuildRequires:  python3-reno
BuildRequires:  python3-sphinxcontrib-svg2pdfconverter

%description -n python-octaviaclient-doc
The Python Octavia Client (python-octaviaclient) is a command-line client for
the OpenStack Load Balancing service.
This package contains auto-generated documentation.

%prep
%autosetup -p1 -n python-octaviaclient-3.7.0
%py_req_cleanup

%build
%{py3_build}

PBR_VERSION=3.7.0 %sphinx_build -b html doc/source doc/build/html
# remove the sphinx-build leftovers
rm -rf doc/build/html/.{doctrees,buildinfo}

%install
%{py3_install}

%check
# we don't want hacking
rm -f octaviaclient/tests/unit/test_hacking.py
%{openstack_stestr_run}

%files -n python3-octaviaclient
%doc README.rst
%license LICENSE
%{python3_sitelib}/octaviaclient
%{python3_sitelib}/*.egg-info

%files -n python-octaviaclient-doc
%license LICENSE
%doc doc/build/html

%changelog
* Sun Mar 24 2024 cloud-devel@suse.de
- update to version 3.7.0
  - Added the vip_vnic_type load balancer field
  - reno: Update master for unmaintained/yoga
  - Bump hacking
  - Update master for stable/2023.2
  - Update python classifier in setup.cfg
* Sun Jan 14 2024 cloud-devel@suse.de
- update to version 3.6.0
  - Bump tox minversion to 3.18.0
  - Fix inconsistency in validation error message for HSTS
  - Update master for stable/zed
  - Fix validation of HSTS attributes
  - Fixing jobs with tox4
  - Add support for HTTP Strict Transport Security
  - Add munch explicitly to requirements
  - Add extra validation for HSTS related arguments
  - Fix new pylint warnings
  - Allow creating/showing LBs with Additional VIPs
  - Remove DELETED from the provisioning status list
  - Drop lower-constraints.txt and its testing
  - Update python testing as per zed cycle testing runtime
  - Remove munch dependency
  - Update master for stable/2023.1
  - Set default value for HSTS options to None
  - Update master for stable/yoga
  - Add missing flavor set --description option
  - Switch to 2023.1 Python3 unit tests and generic template name
  - Clarify the client code is not python bindings
  - Fix inconsistent parameter name in azp
  - Fix pool protocols
  - Add *.orig to .gitignore
* Tue May 24 2022 cloud-devel@suse.de
- update to version 2.5.0
  - Use py3 as the default runtime for tox
  - Ignore new pylint checker
  - Update master for stable/xena
  - Add Python3 yoga unit tests
  - Add support for PROMETHEUS listeners.
* Mon Dec  6 2021 cloud-devel@suse.de
- update to version 2.4.0
  - Support pagination for 'list' API calls
  - Improve the client performance on large clouds
  - Update master for stable/wallaby
  - Fix some typos
  - Add Python3 xena unit tests
  - setup.cfg: Replace dashes with underscores
* Sun May  2 2021 cloud-devel@suse.de
- update to version 2.3.0
  - Remove install unnecessary packages
  - Add support for PROXYV2 protocol
  - Improve error messages in list/show calls
  - Add Python3 wallaby unit tests
  - Update master for stable/victoria
  - Add ALPN support for pools
  - Remove Babel
  - remove unicode from code
  - Fix lower-constraints job
  - Add tag support for Octavia resources
* Fri Oct  9 2020 cloud-devel@suse.de
- update to version 2.2.0
  - Remove mocking of functools.partial
  - Add SCTP support
  - Fix hacking min version to 3.0.1
  - Add TLS versions and ciphers unsets
  - Add the ability to specify TLS protocols for a listener
  - Show operating_status in listing LB output
  - Fix new pylint errors
  - Fix the lower-constraints job for focal
  - Update master for stable/ussuri
  - Add Python3 victoria unit tests
  - Remove Babel requirement
  - Add l7policy and l7rule to octavia quota
  - Add the ability to specify TLS protocols for a pool
  - Add amphora delete command
  - Add ALPN support for listeners
  - Switch to newer openstackdocstheme and reno versions
* Tue May 12 2020 cloud-devel@suse.de
- update to version 2.0.1
  - Add amphora stats show API and CLI
  - Fix Octavia client for API endpoint 503
  - Add the ability to specify the cipher list for a listener
  - Generate PDF documentation
  - Add --long to amphora-list to show more columns
  - Add the ability to specify the cipher list for a pool
  - Align python-octaviaclient to octavia coding style
  - List l7poclies by listener
  - Add "--wait" functionality
  - Drop netifaces from requirements.txt
  - Fix API breakage due to new exceptions module
  - Remove the dependency on the "mock" package
  - Fix long CLI error messages
  - Do not get all resources if ID is passed
  - Stop testing python 2
  - Add support for availability zone [profiles]
  - Add librsvg2-bin/-tools to bindep.txt
  - Cleanup py27 support
  - Update hacking for Python3
  - Update master for stable/train
  - Fix doc8 check
* Wed Mar 11 2020 Dirk Mueller <dmueller@suse.com>
- switch to python 3.x only build
* Wed Oct  9 2019 cloud-devel@suse.de
- update to version 1.10.0
  - Adds "unset" action to the quota command
  - Replace git.openstack.org URLs with opendev.org URLs
  - Wrap several show api calls with correct_return_codes
  - Update master for stable/stein
  - Blacklist sphinx 2.1.0 (autodoc bug)
  - Add support for SOURCE_IP_PORT algorithm
  - OpenDev Migration Patch
  - Adds "unset" action to the l7rule command
  - Remove python3.5 jobs for Train
  - Update tox.ini for new upper constraints strategy
  - Make sure we always requests JSON responses
  - Add Python 3 Train unit tests
  - Fix a bad unit test for amphora list
  - Bump the openstackdocstheme extension to 1.20
  - Adds "unset" action to the loadbalancer command
  - Adds "unset" action to the member command
  - Adds "unset" action to the flavor command
  - Add support to VIP access control list
  - Adds "unset" action to the l7policy command
  - Adds "unset" action to the pool command
  - Adds "unset" action to the listener command
  - Cleanup requirements.txt
  - Adds "unset" action to the healthmonitor command
* Mon Jun 17 2019 cloud-devel@suse.de
- update to version 1.8.1
  - OpenDev Migration Patch
  - Update .gitreview for stable/stein
  - Make sure we always requests JSON responses
  - Update UPPER_CONSTRAINTS_FILE for stable/stein
* Mon Apr  8 2019 cloud-devel@suse.de
- update to version 1.8.0
  - Add 'client_authentication' in Listener on client
  - Add 2 new options to Pool for support backend certificates validation
  - Update json module to jsonutils
  - Make the documentation reproducible
  - Add python 3.6 unit test job
  - Add --provider to load balancer create
  - import zuul job settings from project-config
  - Add provider command support
  - Add 4 l7rule types into Octavia CLI
  - Add new options to HealthMonitor CLI
  - Change openstack-dev to openstack-discuss
  - Update reno for stable/rocky
  - add python 3.6 unit test job
  - Add some commands for octavia flavor and flavor_profile
  - Add Python 3.6 classifier to setup.cfg
  - Fix coverage and set a minimum
  - switch documentation job to new PTI
  - Adds loadbalancer amphora configure to OSC
  - Add compute_flavor field to amphora
  - Add enable_tls option into Pool CLI
  - Fixed some typos
  - Add load balancer flavor support to the OSC client
  - Support REDIRECT_PREFIX for openstack client
  - Add 'tls_container_ref' option into Pool for backend re-encrption
  - Add a new option '--redirect-http-code' into L7Policy CLI
  - Add client_crl_container_ref for Listener API in CLI
  - Add 'client_ca_tls_container_ref' in Listener on client side
  - Add failover an amphora client support
  - add python 3.7 unit test job
  - Use templates for cover and lower-constraints
* Fri Dec 14 2018 Thomas Bechtold <tbechtold@suse.com>
- Initial packaging (version 1.6.0)
